@@ -1,14 +1,14 @@
 import io
-import pytest
-import warnings
 import socket
+import warnings
 from time import monotonic
-
 from unittest.mock import MagicMock, Mock, patch
 
+import pytest
+
 from kombu import Connection
 from kombu.compression import compress
-from kombu.exceptions import ResourceError, ChannelError
+from kombu.exceptions import ChannelError, ResourceError
 from kombu.transport import virtual
 from kombu.utils.uuid import uuid
 
@@ -550,6 +550,13 @@ class test_Transport:
     def setup(self):
         self.transport = client().transport
 
+    def test_state_is_transport_specific(self):
+        # Tests that each Transport of Connection instance
+        # has own state attribute
+        conn1 = client()
+        conn2 = client()
+        assert conn1.transport.state != conn2.transport.state
+
     def test_custom_polling_interval(self):
         x = client(transport_options={'polling_interval': 32.3})
         assert x.transport.polling_interval == 32.3
